import { Component, Inject, NgModule, Optional, ViewEncapsulation } from '@angular/core';
import { FormControlName, FormGroupName } from '@angular/forms';
import { I18NEXT_NAMESPACE, I18NextModule } from 'angular-i18next';
import { ValidationMessageComponent, ValidationMessageModule } from 'angular-validation-message';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class I18NextValidationMessageComponent extends ValidationMessageComponent {
    /**
     * @param {?} i18nextNamespace
     * @param {?} formControlName
     * @param {?} formGroupName
     */
    constructor(i18nextNamespace, formControlName, formGroupName) {
        super(formControlName, formGroupName);
        this.i18nextNamespace = i18nextNamespace;
        this.formControlName = formControlName;
        this.formGroupName = formGroupName;
        this.VALIDATION = 'validation';
    }
    /**
     * @return {?}
     */
    get i18nextKey() {
        if (!this.firstMessage.key)
            return '';
        let /** @type {?} */ specificKey = [this.VALIDATION, ['control_specific', this.controlPath, this.firstMessage.key].join('.')].join(':');
        let /** @type {?} */ commonKey = [this.VALIDATION, this.firstMessage.key].join(':');
        let /** @type {?} */ i18nextKeys = [];
        if (this.i18nextNamespace && this.i18nextNamespace !== this.VALIDATION) {
            i18nextKeys.push([this.i18nextNamespace, specificKey].join('.'));
            i18nextKeys.push([this.i18nextNamespace, commonKey].join('.'));
        }
        i18nextKeys.push(specificKey);
        i18nextKeys.push(commonKey);
        return i18nextKeys;
    }
}
I18NextValidationMessageComponent.decorators = [
    { type: Component, args: [{
                selector: 'i18next-validation-message',
                template: `
      <div class="error-container">{{ i18nextKey | i18nextCap: firstMessage.params }}</div>
    `,
                styles: [`
      i18next-validation-message {
        display: none;
        width: 100%;
        position: relative;
      }
      i18next-validation-message.standalone,
      .ng-dirty.ng-invalid + i18next-validation-message {
        display: block;
      }
    `],
                encapsulation: ViewEncapsulation.None
            },] },
];
/** @nocollapse */
I18NextValidationMessageComponent.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [I18NEXT_NAMESPACE,] },] },
    { type: FormControlName, decorators: [{ type: Optional },] },
    { type: FormGroupName, decorators: [{ type: Optional },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const declarations = [
    I18NextValidationMessageComponent,
];
const providers = [
    {
        provide: ValidationMessageComponent,
        useValue: I18NextValidationMessageComponent
    }
];
class I18NextValidationMessageModule {
}
I18NextValidationMessageModule.decorators = [
    { type: NgModule, args: [{
                declarations: declarations,
                exports: declarations,
                entryComponents: declarations,
                imports: [
                    I18NextModule,
                    ValidationMessageModule
                ],
                providers: providers
            },] },
];
/** @nocollapse */
I18NextValidationMessageModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { I18NextValidationMessageComponent, declarations, providers, I18NextValidationMessageModule };
